% Estimates quadrotor parameters using 'squared' approximation  
% Saves model parameters 
% Carrilho - 19/12/2014 - after checking by Felipe Serrenho 
% 

% clear 
clear, clc, close all
format shorte

% frame
m_f_4a = 5.42e-3;
w_f = 3.5e-2;
d_f = 3.5e-2;
h_f = 2.0e-3;
h_a = 2.0e-3;
w_a = 5.0e-3;
d_a = 2.5e-2;
delta_a = 3.0e-2;

m_f = 49/(20+49)*m_f_4a
m_a = 5/(20+49)*m_f_4a
J_x_f = 1/12*m_f*(h_f^2+d_f^2)+2*(1/12*m_a*(w_a^2+h_a^2))+2*(1/12*m_a*(d_a^2+h_a^2)+m_a*delta_a^2)
J_y_f = 1/12*m_f*(w_f^2+h_f^2)+2*(1/12*m_a*(w_a^2+h_a^2))+2*(1/12*m_a*(d_a^2+h_a^2)+m_a*delta_a^2)
J_z_f = 1/12*m_f*(w_f^2+d_f^2)+4*(1/12*m_a*(w_a^2+d_a^2)+m_a*delta_a^2)

% m_f =
% 
%    3.8490e-03
% 
% 
% m_a =
% 
%    3.9275e-04
% 
% 
% J_x_f =
% 
%    1.1442e-06
% 
% 
% J_y_f =
% 
%    1.1442e-06
% 
% 
% J_z_f =
% 
%    2.2848e-06

% battery 
m_b = 4.85e-3;
w_b = 2.5e-2;
d_b = 2.0e-2;
h_b = 0.5e-2;

J_x_b = 1/12*m_b*(d_b^2+h_b^2)
J_y_b = 1/12*m_b*(w_b^2+h_b^2)
J_z_b = 1/12*m_b*(w_b^2+d_b^2)

% J_x_b =
% 
%    1.7177e-07
% 
% 
% J_y_b =
% 
%    2.6271e-07
% 
% 
% J_z_b =
% 
%    4.1427e-07
   
% Motors and supports 
m_m = 1.65e-3;
m_s = 0.21e-3;
h_m = 1.5e-2;
r_m = 2.5e-3;

J_x_m = 1/12*(m_m+m_s)*(3*r_m^2+h_m^2)
J_y_m = 1/12*(m_m+m_s)*(3*r_m^2+h_m^2)
J_z_m = 1/2*(m_m+m_s)*r_m^2

% J_x_m =
% 
%    3.7781e-08
% 
% 
% J_y_m =
% 
%    3.7781e-08
% 
% 
% J_z_m =
% 
%    5.8125e-09

% Propellers 
m_p = 0.26e-3;
m_pA = 0.23e-3;
w_p = 5e-3;
d_p = 4.5e-3;

J_z_p = 1/12*m_p*(w_p^2+d_p^2)
J_z_pA = 1/12*m_pA*(w_p^2+d_p^2)

% J_z_p =
% 
%    9.8042e-10
% 
% 
% J_z_pA =
% 
%    8.6729e-10
   
% center of mass
z_CM_b = h_b/2;
z_CM_f = -h_f/2;
z_CM_p = 1.0e-2;
z_CM_m = 0;
x_CM_m = 4.5e-2;
y_CM_m = 4.5e-2;

% z_CM should be close to 0 
z_CM = (z_CM_f*(m_f + 4*m_a) + z_CM_b*m_b + 4*z_CM_m*(m_m+m_s) + 2*z_CM_p*m_p ...
    + 2*z_CM_p*m_pA)/...
    (m_f + 4*m_a + m_b + 4*(m_m + m_s) + 2*m_p + 2*m_pA)

% z_CM =
% 
%    8.8309e-04
% it will be considered as 0

% Quadcopter parameters 

m = m_f + 4*m_a + m_b + 4*(m_m + m_s) + 2*m_p + 2*m_pA

Jx = (J_x_f + (m_f + 4*m_a)*z_CM_f^2) + (J_x_b + m_b*z_CM_b^2) + ...
    2*J_x_m + 2*(J_x_m + (m_m + m_s)*y_CM_m^2)

Jy = (J_y_f + (m_f + 4*m_a)*z_CM_f^2) + (J_y_b + m_b*z_CM_b^2) + ...
    2*J_y_m + 2*(J_y_m + (m_m + m_s)*x_CM_m^2)

Jz = J_z_f + J_z_m + 4*(J_z_m + (m_m + m_s)*x_CM_m^2) + ...
    2*(J_z_p + m_p*x_CM_m^2) + 2*(J_z_pA + m_pA*x_CM_m^2)

% m =
% 
%    1.8690e-02
% 
% 
% Jx =
% 
%    9.0359e-06
% 
% 
% Jy =
% 
%    9.1268e-06
% 
% 
% Jz =
% 
%    1.9368e-05

% acceleration of gravity
g = 9.81;

% Saves variables to file 
save model_parameters m Jx Jy Jz g 

   